.. include:: ../README.rst


User's guide
============

.. toctree::
    :maxdepth: 2

    installation
    quickstart


API reference
=============

.. toctree::
    :maxdepth: 2

    api/index


About
=====

.. toctree::
    :maxdepth: 2

    authors
    changelog
    plans
    contributing
